//go:build !runOnTask

// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0
package jobqueue

import (
	"github.com/stretchr/testify/assert"
	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
	"testing"
	"time"
)

func TestWriteToDB3(t *testing.T) {

	db, err := gorm.Open(sqlite.Open("file::memory:?cache=shared"), &gorm.Config{})
	if err != nil {
		t.Fatalf("a error occurred while opening the database: %v", err)
	}

	manager := NewManager()
	manager.SetDB(db)
	err = manager.AddWorker(NewLocalWorker(1))
	assert.Nil(t, err)

	err = manager.Start()
	assert.Nil(t, err)
	runner := &CounterRunnable{}
	job := NewJob[CounterResult]("job2", runner)

	scheduler := &InstantScheduler{}
	err = manager.ScheduleJob(job, scheduler)
	assert.Nil(t, err)

	time.Sleep(1 * time.Second)

	err = manager.DeleteJob(job.GetID())
	assert.Nil(t, err)

	// test is job in database
	var tmpJob JobPersistence
	err = db.First(&tmpJob, "id = ?", "job2").Error
	assert.NotNil(t, err)

}
